'use strict';

const apiWrapper = require('./api-wrapper');
const tools = require('../utils/tools');
const profileHelper = require('../utils/profile-helper');

// Public
module.exports = {
    createCommand: (commander) => {
        buildGetGitCredentialsCommand(commander);
        buildGetAlexaHostedSkillMetadata(commander);
    }
};


function buildGetAlexaHostedSkillMetadata(commander) {
    commander
        .command('get-alexa-hosted-skill')
        .usage('<-s|--skill-id <skill-id>> [-p|--profile <profile>] [--debug]')
        .description('get an alexa hosted skill metadata')
        .option('-s, --skill-id <skill-id>', 'skill-id for the skill')
        .option('-p, --profile <profile>', 'ask cli profile')
        .option('--debug', 'ask cli debug mode')
        .action(handle);

    function handle(options) {
        if (!options.skillId) {
            console.warn('Please input required parameter: skill-id.');
            return;
        }
        let profile = profileHelper.runtimeProfile(options.profile);
        apiWrapper.getHostedSkillMetadata(options.skillId, profile, options.debug, (data) => {
            let response = tools.convertDataToJsonObject(data.body);
            if (response) {
                console.log(JSON.stringify(response, null, 2));
            }
        });
    }
}


function buildGetGitCredentialsCommand(commander) {
    commander
        .command('get-git-credentials')
        .usage('<-s|--skill-id <skill-id>> <-r|--repo-url <repo-url>> [-p|--profile <profile>] [--debug]')
        .description('get the skill\'s git repo credentials (15mn validity)')
        .option('-s, --skill-id <skill-id>', 'skill-id for the skill')
        .option('-r, --repo-url <repo-url>', 'repo-url for the skill')
        .option('-p, --profile <profile>', 'ask cli profile')
        .option('--debug', 'ask cli debug mode')
        .action(handle);

    function handle(options) {
        if (!options.skillId) {
            console.warn('Please input required parameter: skill-id.');
            return;
        }
        if (!options.repoUrl) {
            console.warn('Please input required parameter: repo-url.');
            return;
        }
        const profile = profileHelper.runtimeProfile(options.profile);
        apiWrapper.getGitCredentials(options.skillId, options.repoUrl, profile, options.debug, (data) => {
            const response = tools.convertDataToJsonObject(data.body);
            if (response) {
                console.log(JSON.stringify(response, null, 2));
            }
        });
    }
}
