const { expect } = require('chai');
const sinon = require('sinon');
const inquirer = require('inquirer');
const ui = require('@src/commands/create-hosted-skill/ui');

describe('Commands create-hosted-skill - UI test', () => {
    const TEST_SKILL_NAME = 'testSkillName';
    const TEST_RUN_TIME = 'nodejs8.10';

    describe('# getSkillName check', () => {
        beforeEach(() => {
            sinon.stub(inquirer, 'prompt');
        });

        it('| getSkillName is defined by user return correctly', (done) => {
            // call
            ui.getSkillName(TEST_SKILL_NAME, (err, response) => {
                // verify
                expect(err).equal(null);
                expect(response).equal(TEST_SKILL_NAME);
                done();
            });
        });

        it('| getSkillName retrieves user input correctly', (done) => {
            // setup
            inquirer.prompt.resolves({ skillName: TEST_SKILL_NAME });
            // call
            ui.getSkillName(null, (err, response) => {
                // verify
                expect(err).equal(null);
                expect(response).equal(TEST_SKILL_NAME);
                done();
            });
        });

        afterEach(() => {
            inquirer.prompt.restore();
        });
    });

    describe('# getRunTime check', () => {
        beforeEach(() => {
            sinon.stub(inquirer, 'prompt');
        });

        it('| runtTime is defined by user return correctly', (done) => {
            ui.getRunTime(TEST_RUN_TIME, (err, response) => {
                expect(err).equal(null);
                expect(response).equal(TEST_RUN_TIME);
                done();
            });
        });

        it('| runtTime is defined by user but invalid runtime value', (done) => {
            ui.getRunTime('INVALID_RUNTIME', (err, response) => {
                expect(err).equal('[Error]: Invalid runtime. Please run "ask create-hosted-skill -h" for help.');
                expect(response).equal(null);
                done();
            });
        });

        it('| runtTime entered by user is retrieved correctly', (done) => {
            // setup
            inquirer.prompt.resolves({ runTime: TEST_RUN_TIME });
            // call
            ui.getRunTime(null, (err, response) => {
                // verify
                expect(err).equal(null);
                expect(response).equal(TEST_RUN_TIME);
                done();
            });
        });

        afterEach(() => {
            inquirer.prompt.restore();
        });
    });

    describe('# getAutoClone check', () => {
        beforeEach(() => {
            sinon.stub(inquirer, 'prompt');
        });

        it('| autoClone is defined by user return correctly', (done) => {
            // call
            ui.getAutoClone('true', (err, response) => {
                // verify
                expect(err).equal(null);
                expect(response).equal(true);
                done();
            });
        });

        it('| no options input, autoClone is retrieved correctly', (done) => {
            // setup
            inquirer.prompt.resolves({ isAllowed: true });
            // call
            ui.getAutoClone(null, (err, response) => {
                // verify
                expect(err).equal(null);
                expect(response).equal(true);
                done();
            });
        });

        afterEach(() => {
            inquirer.prompt.restore();
        });
    });

    describe('# getConfirmation check', () => {
        beforeEach(() => {
            sinon.stub(inquirer, 'prompt');
        });

        it('| confirmation entered by user is retrieved correctly', (done) => {
            // setup
            const TEST_CONFIRMATION = 'y';
            inquirer.prompt.resolves({confirmation : TEST_CONFIRMATION });
            // call
            ui.getConfirmation((response) => {
                // verify
                expect(response).equal(TEST_CONFIRMATION);
                done();
            });
        });

        afterEach(() => {
            inquirer.prompt.restore();
        });
    });
});
